| check_folds | R Documentation |
(Internal) function that checks if folds result from subsampling with p = 0.5 and adds complementary pairs if needed.
check_folds(folds, B, n, sampling.type)
folds |
a weight matrix that represents the subsamples. |
B |
number of subsampling replicates. |
n |
the number of observations; needed for internal checks. |
sampling.type |
sampling type to be used. |
This is an internal function used to check if folds are
specified correctly. For details (e.g. on arguments) see
stabsel.
A matrix containing the folds, possibly after adding the
complementary pairs.
B. Hofner, L. Boccuto and M. Goeker (2015), Controlling false
discoveries in high-dimensional situations: Boosting with stability
selection. BMC Bioinformatics, 16:144.
\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1186/s12859-015-0575-3")}.
For details see stabsel.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.